backgroundColor property
Color?
backgroundColor
getter/setter pair
The suggested background color to clear the canvas with.
Implementation
Color? backgroundColor;
The suggested background color to clear the canvas with.
Color? backgroundColor;